import { AfterViewInit, ApplicationRef, ComponentFactoryResolver, EventEmitter, Injector, Renderer2, TemplateRef } from '@angular/core';
import { Subject } from 'rxjs';
import { WalkthroughContainerComponent } from './walkthrough-container.component';
import { WalkthroughTextI } from './walkthrough-text';
import { WalkthroughEvent } from './walkthrough-tools';
import { WalkthroughService } from './walkthrough.service';
export interface WalkthroughNavigate {
    previous: WalkthroughComponent;
    next: WalkthroughComponent;
}
export declare class WalkthroughComponent implements AfterViewInit {
    private _componentFactoryResolver;
    private _applicationRef;
    private _injector;
    private _renderer;
    private _walkthroughService;
    private static _walkthroughContainer;
    private static _walkthroughContainerCreating;
    static minimalMargin: number;
    static onOpen: Subject<WalkthroughComponent>;
    static onRefresh: Subject<WalkthroughComponent>;
    static onClose: Subject<WalkthroughComponent>;
    static onNavigate: Subject<WalkthroughNavigate>;
    static onNavigatePrevious: Subject<WalkthroughNavigate>;
    static onNavigateNext: Subject<WalkthroughNavigate>;
    static onFinish: Subject<WalkthroughComponent>;
    closed: EventEmitter<boolean>;
    finished: EventEmitter<WalkthroughEvent>;
    ready: EventEmitter<WalkthroughEvent>;
    focusElementCSSClass: string;
    rootElement: string;
    focusElementSelector: string;
    typeSelector: 'element' | 'zone';
    focusClick: (event: Event, content: WalkthroughContainerComponent) => {};
    radius: string;
    previousStep: WalkthroughComponent;
    nextStep: WalkthroughComponent;
    texts: WalkthroughTextI;
    contentTemplate: TemplateRef<any>;
    contentText: string;
    contentStyle: 'none' | 'draken';
    get marginZone(): string | null;
    set marginZone(points: string | null);
    get arrowColor(): string;
    set arrowColor(color: string);
    animation: 'none' | 'linear';
    animationDelays: number;
    get id(): string;
    set id(value: string);
    get alignContent(): 'left' | 'center' | 'right';
    set alignContent(value: 'left' | 'center' | 'right');
    get verticalAlignContent(): 'above' | 'top' | 'center' | 'bottom' | 'below';
    set verticalAlignContent(value: 'above' | 'top' | 'center' | 'bottom' | 'below');
    get contentSpacing(): number;
    set contentSpacing(value: number);
    get verticalContentSpacing(): number;
    set verticalContentSpacing(value: number);
    get closeButton(): string | boolean;
    set closeButton(value: string | boolean);
    get closeAnywhere(): string | boolean;
    set closeAnywhere(value: string | boolean);
    get showArrow(): string | boolean;
    set showArrow(value: string | boolean);
    get finishButton(): string | boolean;
    set finishButton(value: string | boolean);
    get focusHighlightAnimation(): string | boolean;
    set focusHighlightAnimation(value: string | boolean);
    get focusBackdrop(): string | boolean;
    set focusBackdrop(value: string | boolean);
    get focusGlow(): string | boolean;
    set focusGlow(value: string | boolean);
    get disabled(): boolean;
    set disabled(value: boolean);
    scrollOnTarget: boolean;
    visibilityCallback: Function;
    private _id;
    private _uid;
    private _readyHasBeenEmited;
    private _display;
    private _hasHighlightAnimation;
    private _hasBackdrop;
    private _hasGlow;
    private _hasFinish;
    private _hasArrow;
    private _hasCloseButton;
    private _hasCloseAnywhere;
    private _disabled;
    private _arrowColor;
    private _marginZone;
    private _marginZonePx;
    private _alignContent;
    private _verticalAlignContent;
    private _contentSpacing;
    private _verticalContentSpacing;
    private _focusElement;
    private _focusElementEnd;
    private _offsetCoordinates;
    private _onContainerInit;
    private _onResize;
    static walkthroughStop(): void;
    static walkthroughHasShow(): boolean;
    static walkthroughHasPause(): boolean;
    static walkthroughContinue(): void;
    static walkthroughNext(): void;
    static walkthroughPrevious(): void;
    constructor(_componentFactoryResolver: ComponentFactoryResolver, _applicationRef: ApplicationRef, _injector: Injector, _renderer: Renderer2, _walkthroughService: WalkthroughService);
    resize(): void;
    ngAfterViewInit(): void;
    next(closedEvent?: EventEmitter<boolean>, finishedEvent?: EventEmitter<WalkthroughEvent>): void;
    refresh(): void;
    open(): Promise<boolean>;
    /**
     * Do not use this method outside of the library
     */
    loadPrevioustStep(): void;
    /**
     * Do not use this method outside of the library
     */
    loadNextStep(): void;
    /**
     * Do not use this method outside of the library
     */
    hide(finishLink?: boolean, closeWalkthrough?: boolean): void;
    private _checkVisibility;
    private _open;
    private _show;
    private _next;
    private _getInstance;
    private _appendComponentToBody;
    private _attachWalkthroughContent;
    private _elementLocations;
    /**
     *
     */
    private _getFocusElement;
    /**
     * get instance, hightlight the focused element et show the template
     */
    private _setFocus;
    private _setFocusContinue;
    private _updateElementPositions;
    /**
     * Attache the template in the contener, if a template is linked.
     */
    private _attachContentTemplate;
    /**
     * init a partof styles of the contenaire
     */
    private _initStylingTemplate;
    /**
     * init all datas of the contenaire
     */
    private _initContentTemplate;
    /**
     * check if there is a previous step enabled
     */
    private _hasPreviousStep;
    /**
     * check if there is a next step enabled
     */
    private _hasNextStep;
}
